# ShrtCde (ShortCode)
A small python library for lazy devs. This shortens the amount of code you have to write for your program with the help of functions.

If you find a bug, feel free to report it!

Wiki coming soon.
